==> mx-packageinstaller-pkglist_19.05.09.tar.xz: mx-packageinstaller-pkglist/mirage.pm <==
<?xml version="1.0"?>
<app>

<category>
Graphics
</category>

<name>
Mirage
</name>

<description>
   <am>fast and simple image viewer</am>
   <ar>fast and simple image viewer</ar>
   <bg>fast and simple image viewer</bg>
   <ca>visor d'imatges senzill i ràpid</ca>
   <cs>fast and simple image viewer</cs>
   <da>hurtig og simpel billedfremviser</da>
   <de>Schneller und einfacher Bildbetrachter</de>
   <el>γρήγορο και απλό πρόγραμμα προβολής εικόνων</el>
   <en>fast and simple image viewer</en>
   <es>visor de imágenes rápido y simple</es>
   <et>fast and simple image viewer</et>
   <eu>fast and simple image viewer</eu>
   <fa>fast and simple image viewer</fa>
   <fi>fast and simple image viewer</fi>
   <fr>Visionneuse d'images facile et rapide</fr>
   <he_IL>fast and simple image viewer</he_IL>
   <hi>fast and simple image viewer</hi>
   <hr>fast and simple image viewer</hr>
   <hu>fast and simple image viewer</hu>
   <id>fast and simple image viewer</id>
   <is>fast and simple image viewer</is>
   <it>visualizzatore di immagini semplice e veloce</it>
   <ja_JP>fast and simple image viewer</ja_JP>
   <ja>fast and simple image viewer</ja>
   <kk>fast and simple image viewer</kk>
   <ko>fast and simple image viewer</ko>
   <lt>fast and simple image viewer</lt>
   <mk>fast and simple image viewer</mk>
   <nb>fast and simple image viewer</nb>
   <nl>snelle en eenvoudige afbeeldingsweergave</nl>
   <pl>szybka i prosta przeglądarka grafiki i zdjęć</pl>
   <pt_BR>fast and simple image viewer</pt_BR>
   <pt>Visualizador de imagens rápido e simples</pt>
   <ro>fast and simple image viewer</ro>
   <ru>Быстрый и простой просмотрщик изображений</ru>
   <sk>fast and simple image viewer</sk>
   <sl>fast and simple image viewer</sl>
   <sq>fast and simple image viewer</sq>
   <sr>fast and simple image viewer</sr>
   <sv>snabb och enkel bildvisare</sv>
   <tr>fast and simple image viewer</tr>
   <uk>швидкий та простий переглядач зображень</uk>
   <zh_CN>fast and simple image viewer</zh_CN>
   <zh_TW>fast and simple image viewer</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>http://screenshots.debian.net/screenshots/000/005/675/large.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
mirage
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
mirage
</uninstall_package_names>
</app>

==> mx-packageinstaller-pkglist_19.09.03.tar.xz: mx-packageinstaller-pkglist/mirage.pm <==
<?xml version="1.0"?>
<app>

<category>
Graphics
</category>

<name>
Mirage
</name>

<description>
   <am>fast and simple image viewer</am>
   <ar>fast and simple image viewer</ar>
   <bg>fast and simple image viewer</bg>
   <ca>visor d'imatges senzill i ràpid</ca>
   <cs>fast and simple image viewer</cs>
   <da>hurtig og simpel billedfremviser</da>
   <de>Schneller und einfacher Bildbetrachter</de>
   <el>γρήγορο και απλό πρόγραμμα προβολής εικόνων</el>
   <en>fast and simple image viewer</en>
   <es>Visor de imágenes rápido y simple</es>
   <et>fast and simple image viewer</et>
   <eu>fast and simple image viewer</eu>
   <fa>fast and simple image viewer</fa>
   <fi>fast and simple image viewer</fi>
   <fr>Visionneuse d'images facile et rapide</fr>
   <he_IL>fast and simple image viewer</he_IL>
   <hi>fast and simple image viewer</hi>
   <hr>fast and simple image viewer</hr>
   <hu>fast and simple image viewer</hu>
   <id>fast and simple image viewer</id>
   <is>fast and simple image viewer</is>
   <it>visualizzatore di immagini semplice e veloce</it>
   <ja_JP>fast and simple image viewer</ja_JP>
   <ja>fast and simple image viewer</ja>
   <kk>fast and simple image viewer</kk>
   <ko>fast and simple image viewer</ko>
   <lt>greita ir paprasta paveikslų žiūryklė</lt>
   <mk>fast and simple image viewer</mk>
   <nb>fast and simple image viewer</nb>
   <nl>snelle en eenvoudige afbeeldingsweergave</nl>
   <pl>szybka i prosta przeglądarka grafiki i zdjęć</pl>
   <pt_BR>Visualizador de imagens rápido e simples</pt_BR>
   <pt>Visualizador de imagens rápido e simples</pt>
   <ro>fast and simple image viewer</ro>
   <ru>Быстрый и простой просмотрщик изображений</ru>
   <sk>fast and simple image viewer</sk>
   <sl>fast and simple image viewer</sl>
   <sq>fast and simple image viewer</sq>
   <sr>fast and simple image viewer</sr>
   <sv>snabb och enkel bildvisare</sv>
   <tr>fast and simple image viewer</tr>
   <uk>швидкий та простий переглядач зображень</uk>
   <zh_CN>fast and simple image viewer</zh_CN>
   <zh_TW>fast and simple image viewer</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>http://screenshots.debian.net/screenshots/000/005/675/large.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
mirage
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
mirage
</uninstall_package_names>
</app>
